@@ -1,11 +1,11 @@
 /*
  *  agShell
- *  $Id: agShell.c,v 4.10 2006/01/28 21:26:40 bkorb Exp $
+ *  $Id: agShell.c,v 4.11 2006/06/24 23:36:07 bkorb Exp $
  *  Manage a server shell process
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -103,6 +103,10 @@ closeServer( void )
 static void
 sigHandler( int signo )
 {
+    static int timeout_limit = 5;
+    if ((signo == SIGALRM) && (--timeout_limit <= 0))
+        AG_ABEND( "Server shell timed out 5 times" );
+
     fprintf( pfTrace, "Closing server:  %s signal (%d) received\n",
              strsignal( signo ), signo );
     errClose = AG_TRUE;
@@ -540,6 +544,8 @@ runShell( const char*  pzCmd )
      *  THEN try to start it.
      */
     if (serverId == NULLPROCESS) {
+        static char pz4_z[] = "PS4=>ag> ";
+        putenv(pz4_z);
         serverId = openServerFP( &serverPair, serverArgs );
         if (serverId > 0)
             serverSetup();
