@@ -1,7 +1,7 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 4.13 2006/03/25 19:24:49 bkorb Exp $
+ *  $Id: autogen.h,v 4.19 2006/08/12 17:36:43 bkorb Exp $
  *  Global header file for AutoGen
  */
 
@@ -24,13 +24,14 @@
  *             51 Franklin Street, Fifth Floor,
  *             Boston, MA  02110-1301, USA.
  */
-#ifndef AUTOGEN_HDR_H
-#define AUTOGEN_HDR_H
+#ifndef AUTOGEN_BUILD
+#define AUTOGEN_BUILD 1
 
 #include "config.h"
 #include "compat/compat.h"
 
 #include REGEX_HEADER
+#include <libguile/scmconfig.h>
 #include <guile/gh.h>
 
 #include "opts.h"
@@ -373,9 +374,9 @@ MODE int         templLineNo      VALUE( 1 );
 MODE tScanCtx*   pBaseCtx         VALUE( NULL );
 MODE tScanCtx*   pCurCtx          VALUE( NULL );
 MODE tScanCtx*   pDoneCtx         VALUE( NULL );
-MODE int         endMacLen        VALUE( 0  );
+MODE u_int       endMacLen        VALUE( 0  );
 MODE char        zEndMac[   8 ]   VALUE( "" );
-MODE int         startMacLen      VALUE( 0  );
+MODE u_int       startMacLen      VALUE( 0  );
 MODE char        zStartMac[  8 ]  VALUE( "" );
 MODE int         guileFailure     VALUE( 0 );
 
@@ -409,6 +410,7 @@ MKSTRING( ShDone,     "ShElL-OuTpUt-HaS-bEeN-cOmPlEtEd" );
 MKSTRING( NotStr,     "ERROR: %s is not a string\n" );
 MKSTRING( DevNull,    "/dev/null" );
 MKSTRING( ShellEnv,   "SHELL" );
+MKSTRING( Format,     "format" );
 
 /*
  *  It may seem odd that there are two 'nil' strings.  It is used by
@@ -478,6 +480,7 @@ extern char* ag_scribble( size_t size );
 
 # define AG_SCM_STRLEN(_s)       SCM_LENGTH(_s)
 # define AG_SCM_STRING_P(_s)     gh_string_p(_s)
+# define AG_SCM_NUMBER_P(_s)     gh_number_p(_s)
 # define AG_SCM_BOOL_P(_b)       gh_boolean_p(_b)
 # define AG_SCM_SYM_P(_s)        gh_symbol_p(_s)
 # define AG_SCM_IS_PROC(_p)      gh_procedure_p(_p)
@@ -512,6 +515,7 @@ static inline char* ag_scm2zchars( SCM s, tCC* type )
 
 # define AG_SCM_STRLEN(_s)       SCM_LENGTH(_s)
 # define AG_SCM_STRING_P(_s)     SCM_STRINGP(_s)
+# define AG_SCM_NUMBER_P(_s)     SCM_NUMBERP(_s)
 # define AG_SCM_BOOL_P(_b)       SCM_BOOLP(_b)
 # define AG_SCM_SYM_P(_s)        SCM_SYMBOLP(_s)
 # define AG_SCM_IS_PROC(_p)      SCM_NFALSEP( scm_procedure_p(_p))
@@ -546,13 +550,22 @@ static inline char* ag_scm2zchars( SCM s, tCC* type )
 #else
   extern char* ag_scm2zchars( SCM s, tCC* type );
 
-# define AG_SCM_STRLEN(_s)       SCM_STRING_LENGTH(_s)
+# if GUILE_VERSION < 108000
+#   define AG_SCM_STRLEN(_s)     SCM_STRING_LENGTH(_s)
+#   define AG_SCM_CHARS(_s)      SCM_STRING_CHARS(_s)
+#   define AG_SCM_VEC_P(_v)      SCM_VECTORP(_v)
+# else
+#   define AG_SCM_STRLEN(_s)     scm_c_string_length(_s)
+#   define AG_SCM_CHARS(_s)      SCM_STRING_CHARS(_s)
+#   define AG_SCM_VEC_P(_v)      scm_is_vector(_v)
+# endif
+
 # define AG_SCM_STRING_P(_s)     scm_is_string(_s)
+# define AG_SCM_NUMBER_P(_s)     scm_is_number(_s)
 # define AG_SCM_BOOL_P(_b)       SCM_BOOLP(_b)
 # define AG_SCM_SYM_P(_s)        SCM_SYMBOLP(_s)
 # define AG_SCM_IS_PROC(_p)      scm_is_true( scm_procedure_p(_p))
 # define AG_SCM_CHAR_P(_c)       SCM_CHARP(_c)
-# define AG_SCM_VEC_P(_v)        SCM_VECTORP(_v)
 # define AG_SCM_PAIR_P(_p)       scm_is_true( scm_pair_p(_p))
 # define AG_SCM_NUM_P(_n)        SCM_NUMBERP(_n)
 # define AG_SCM_LIST_P(_l)       SCM_NFALSEP( scm_list_p(_l))
@@ -560,7 +573,6 @@ static inline char* ag_scm2zchars( SCM s, tCC* type )
 # define AG_SCM_MKSTR(_s, _ch)   MUST NOT USE
 
 # define AG_SCM_EVAL_STR(_s)     scm_c_eval_string(_s)
-# define AG_SCM_CHARS(_s)        SCM_STRING_CHARS(_s)
 # define AG_SCM_STR2SCM(_st,_sz) scm_from_locale_stringn(_st,_sz)
 # define AG_SCM_STR02SCM(_s)     scm_from_locale_string(_s)
 # define AG_SCM_INT2SCM(_i)      gh_int2scm(_i)
@@ -582,7 +594,7 @@ static inline SCM ag_eval( tCC* pzStr )
     return res;
 }
 
-#endif /* AUTOGEN_HDR */
+#endif /* AUTOGEN_BUILD */
 /*
  * Local Variables:
  * mode: C
