@@ -1,12 +1,18 @@
-
 /*
  *  defDirect.c
- *  $Id: defDirect.c,v 4.6 2005/06/07 22:26:43 bkorb Exp $
+ *  $Id: defDirect.c,v 4.8 2006/07/22 04:50:19 bkorb Exp $
  *  This module processes definition file directives.
+ *
+ *  blocksort spacing=2 \
+ *    output=defDirect-sorted.c \
+ *    input=defDirect.c \
+ *    pat='^/\*=directive' \
+ *    start='^doDir_IGNORE' \
+ *    trail='\+\+\+ End of Directives'
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -32,63 +38,9 @@ tSCC zCheckList[] = "\n#";
 
 static int  ifdefLevel = 0;
 
-/* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
 static teDirectives
 findDirective( char* pzDirName );
 
-static char*
-skipToEndif( char* pzScan );
-
-static char*
-skipToElseEnd( char* pzScan );
-
-static char*
-doDir_IGNORE( char* pzArg, char* pzScan );
-
-static char*
-doDir_define( char* pzArg, char* pzScan );
-
-static char*
-doDir_elif( char* pzArg, char* pzScan );
-
-static char*
-doDir_else( char* pzArg, char* pzScan );
-
-static char*
-doDir_endif( char* pzArg, char* pzScan );
-
-static char*
-doDir_endshell( char* pzArg, char* pzScan );
-
-static char*
-doDir_error( char* pzArg, char* pzScan );
-
-static char*
-doDir_if( char* pzArg, char* pzScan );
-
-static char*
-doDir_ifdef( char* pzArg, char* pzScan );
-
-static char*
-doDir_ifndef( char* pzArg, char* pzScan );
-
-static char*
-doDir_include( char* pzArg, char* pzScan );
-
-static char*
-doDir_line( char* pzArg, char* pzScan );
-
-static char*
-doDir_option( char* pzArg, char* pzScan );
-
-static char*
-doDir_shell( char* pzArg, char* pzScan );
-
-static char*
-doDir_undef( char* pzArg, char* pzScan );
-/* = = = END-STATIC-FORWARD = = = */
-
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *  processDirective
@@ -202,7 +154,7 @@ findDirective( char* pzDirName )
 
     do  {
         if (  (strneqvcmp( pzDirName, pTbl[res].pzDirName,
-                           pTbl[res].nameSize ) == 0)
+                           (int)pTbl[res].nameSize ) == 0)
            && (  isspace( pzDirName[ pTbl[res].nameSize ])
               || (pzDirName[ pTbl[res].nameSize ] == NUL) )  )
             return res;
@@ -239,19 +191,21 @@ findDirective( char* pzDirName )
  *  while skipping a block of text due to a failed test.
  */
 static char*
-skipToEndif( char* pzScan )
+skipToEndif( char* pzStart )
 {
+    char* pzScan = pzStart;
+    char* pzRet;
+
     for (;;) {
-        char*  pz;
         /*
          *  'pzScan' is pointing to the first character on a line.
          *  Check for a directive on the current line before scanning
          *  later lines.
          */
         if (*pzScan == '#')
-            pz = ++pzScan;
+            pzScan++;
         else {
-            pz = strstr( pzScan, zCheckList );
+            char* pz = strstr( pzScan, zCheckList );
             if (pz == NULL)
                 AG_ABEND( aprf( zNoEndif, pCurCtx->pzCtxFname,
                                 pCurCtx->lineNo ));
@@ -269,8 +223,9 @@ skipToEndif( char* pzScan )
              */
             char* pz = strchr( pzScan, '\n' );
             if (pz != NULL)
-                return pz+1;
-            return pzScan + strlen( pzScan );
+                 pzRet = pz+1;
+            else pzRet = pzScan + strlen( pzScan );
+            goto leave;
         }
 
         case DIR_IFDEF:
@@ -288,6 +243,58 @@ skipToEndif( char* pzScan )
             break; /* ignore it */
         }  /* switch (findDirective( pzScan )) */
     }
+
+ leave:
+    while (pzStart < pzRet) {
+        if (*(pzStart++) == '\n')
+            pCurCtx->lineNo++;
+    }
+    return pzRet;
+}
+
+
+static char*
+skipToEndmac( char* pzStart )
+{
+    char* pzScan = pzStart;
+    char* pzRet;
+
+    for (;;) {
+        /*
+         *  'pzScan' is pointing to the first character on a line.
+         *  Check for a directive on the current line before scanning
+         *  later lines.
+         */
+        if (*pzScan == '#')
+            pzScan++;
+        else {
+            char* pz = strstr( pzScan, zCheckList );
+            if (pz == NULL)
+                AG_ABEND( aprf( zNoEndif, pCurCtx->pzCtxFname,
+                                pCurCtx->lineNo ));
+
+            pzScan = pz + STRSIZE( zCheckList );
+        }
+
+        while (isspace( *pzScan )) pzScan++;
+
+        if (findDirective( pzScan ) == DIR_ENDMAC) {
+            /*
+             *  We found the endmac we are interested in
+             */
+            char* pz = strchr( pzScan, '\n' );
+            if (pz != NULL)
+                 pzRet = pz+1;
+            else pzRet = pzScan + strlen( pzScan );
+            break;
+        }
+    }
+
+    while (pzStart < pzRet) {
+        if (*(pzStart++) == '\n')
+            pCurCtx->lineNo++;
+    }
+    return pzRet;
 }
 
 
@@ -299,19 +306,21 @@ skipToEndif( char* pzScan )
  *  "#if*def" test.
  */
 static char*
-skipToElseEnd( char* pzScan )
+skipToElseEnd( char* pzStart )
 {
+    char* pzScan = pzStart;
+    char* pzRet;
+
     for (;;) {
-        char*  pz;
         /*
          *  'pzScan' is pointing to the first character on a line.
          *  Check for a directive on the current line before scanning
          *  later lines.
          */
         if (*pzScan == '#')
-            pz = ++pzScan;
+            pzScan++;
         else {
-            pz = strstr( pzScan, zCheckList );
+            char* pz = strstr( pzScan, zCheckList );
             if (pz == NULL)
                 AG_ABEND( aprf( zNoEndif, pCurCtx->pzCtxFname,
                                 pCurCtx->lineNo ));
@@ -339,8 +348,9 @@ skipToElseEnd( char* pzScan )
              */
             char* pz = strchr( pzScan, '\n' );
             if (pz != NULL)
-                return pz+1;
-            return pzScan + strlen( pzScan );
+                 pzRet = pz+1;
+            else pzRet = pzScan + strlen( pzScan );
+            goto leave;
         }
 
         case DIR_IFDEF:
@@ -360,6 +370,13 @@ skipToElseEnd( char* pzScan )
             break;
         }  /* switch (findDirective( pzScan )) */
     }
+
+ leave:
+    while (pzStart < pzRet) {
+        if (*(pzStart++) == '\n')
+            pCurCtx->lineNo++;
+    }
+    return pzRet;
 }
 
 
@@ -385,8 +402,73 @@ doDir_IGNORE( char* pzArg, char* pzScan )
 
 /*=directive assert
  *
- *  dummy:  Assert directives are ignored.
+ *  arg:  `shell-script` | (scheme-expr) | <anything else>
+ *
+ *  text:
+ *  If the @code{shell-script} or @code{scheme-expr} do not yield @code{true}
+ *  valued results, autogen will be aborted.  If @code{<anything else>} or
+ *  nothing at all is provided, then this directive is ignored.
+ *
+ *  When writing the shell script, remember this is on a preprocessing
+ *  line.  Multiple lines must be backslash continued and the result is a
+ *  single long line.  Separate multiple commands with semi-colons.
+ *
+ *  The result is @code{false} (and fails) if the result is empty, the
+ *  number zero, or a string that starts with the letters 'n' or 'f' ("no"
+ *  or "false").
 =*/
+static void
+check_assert_str( const char* pz, const char* pzArg )
+{
+    static const char fmt[] = "#assert yielded \"%s\":\n\t`%s`";
+
+    while (isspace(*pz)) pz++;
+
+    if (isdigit(*pz)) {
+        if (atoi(pz) == 0)
+            AG_ABEND( aprf( fmt, "0 (zero)", pzArg ));
+
+    } else switch (*pz) {
+    case 'f': case 'F': case 'n': case 'N': case NUL:
+        AG_ABEND( aprf( fmt, pz, pzArg ));
+    }
+}
+
+static char*
+doDir_assert( char* pzArg, char* pzScan )
+{
+    switch (*pzArg) {
+    case '`':
+    {
+        char* pzS = pzArg+1;
+        char* pzR;
+
+        pzR = strrchr(pzS, '`');
+        if (pzR == NULL)
+            break; /* not a valid script */
+
+        *pzR = NUL;
+        pzS = runShell( (const char*)pzS );
+        check_assert_str( pzS, pzArg );
+        free(pzS);
+        break;
+    }
+
+    case '(':
+    {
+        SCM res = ag_scm_c_eval_string_from_file_line(
+            pzArg, pCurCtx->pzCtxFname, pCurCtx->lineNo );
+        tCC* pzR = resolveSCM( res );
+        check_assert_str( pzR, pzArg );
+        break;
+    }
+
+    default:
+        break;
+    }
+
+    return pzScan;
+}
 
 
 /*=directive define
@@ -515,6 +597,21 @@ doDir_endif( char* pzArg, char* pzScan )
 }
 
 
+/*=directive endmac
+ *
+ *  text:
+ *  This terminates a "macdef", but must not ever be encountered directly.
+=*/
+static char*
+doDir_endmac( char* pzArg, char* pzScan )
+{
+    AG_ABEND( aprf( zNoMatch, pCurCtx->pzCtxFname, pCurCtx->lineNo,
+                    "endmac" ));
+    /* NOTREACHED */
+    return NULL;
+}
+
+
 /*=directive endshell
  *
  *  text:
@@ -580,12 +677,12 @@ doDir_if( char* pzArg, char* pzScan )
  *  text:
  *  The definitions that follow, up to the matching @code{#endif} will be
  *  processed only if there is a corresponding @code{-Dname} command line
- *  option.
+ *  option or if a @code{#define} of that name has been previously encountered.
 =*/
 static char*
 doDir_ifdef( char* pzArg, char* pzScan )
 {
-    if (getDefine( pzArg ) == NULL)
+    if (getDefine( pzArg, AG_FALSE ) == NULL)
         return skipToElseEnd( pzScan );
     ifdefLevel++;
     return pzScan;
@@ -604,7 +701,7 @@ doDir_ifdef( char* pzArg, char* pzScan )
 static char*
 doDir_ifndef( char* pzArg, char* pzScan )
 {
-    if (getDefine( pzArg ) != NULL)
+    if (getDefine( pzArg, AG_FALSE ) != NULL)
         return skipToElseEnd( pzScan );
     ifdefLevel++;
     return pzScan;
@@ -721,6 +818,12 @@ doDir_include( char* pzArg, char* pzScan )
 }
 
 
+/*=directive let
+ *
+ *  dummy:  let directives are ignored.
+=*/
+
+
 /*=directive line
  *
  *  text:
@@ -765,6 +868,19 @@ doDir_line( char* pzArg, char* pzScan )
 }
 
 
+/*=directive macdef
+ *
+ *  text:
+ *  This is a new AT&T research preprocessing directive.  Basically, it is
+ *  a multi-line #define that may include other preprocessing directives.
+=*/
+static char*
+doDir_macdef( char* pzArg, char* pzScan )
+{
+    return skipToEndmac( pzScan );
+}
+
+
 /*=directive option
  *
  *  arg:  opt-name [ <text> ]
@@ -833,12 +949,18 @@ doDir_shell( char* pzArg, char* pzScan )
     if (strncmp( pzText, zEndShell+1, STRSIZE( zEndShell )-1) == 0)
         return pzScan;
 
-    pzScan = strstr( pzScan, zEndShell );
-    if (pzScan == NULL)
-        AG_ABEND( aprf( "Missing #endshell after '#shell' in %s on line %d\n",
-                        pCurCtx->pzCtxFname, pCurCtx->lineNo ));
+    {
+        char* pz = strstr( pzScan, zEndShell );
+        if (pz == NULL)
+            AG_ABEND( aprf("Missing #endshell after '#shell' in %s on line %d\n",
+                           pCurCtx->pzCtxFname, pCurCtx->lineNo ));
 
-    *pzScan = NUL;
+        while (pzScan < pz) {
+            if (*(pzScan++) == '\n') pCurCtx->lineNo++;
+        }
+
+        *pzScan = NUL;
+    }
 
     /*
      *  Advance the scan pointer to the next line after '#endshell'
@@ -847,7 +969,7 @@ doDir_shell( char* pzArg, char* pzScan )
      */
     pzScan = strchr( pzScan + STRSIZE( zEndShell ), '\n' );
     if (pzScan == NULL)
-        pzScan = "";
+        pzScan = (void*)zNil;
 
     /*
      *  Save the scan pointer into the current context
@@ -855,7 +977,7 @@ doDir_shell( char* pzArg, char* pzScan )
     pCurCtx->pzScan  = pzScan;
 
     if (pzShellProgram == NULL)
-        pzShellProgram = getDefine( zShellEnv );
+        pzShellProgram = getDefine( zShellEnv, AG_TRUE );
 
     /*
      *  Run the shell command.  The output text becomes the
@@ -909,6 +1031,7 @@ doDir_undef( char* pzArg, char* pzScan )
     return pzScan;
 }
 
+
 /*+++ End of Directives +++*/
 /*
  * Local Variables:
