@@ -1,11 +1,11 @@
 /*
- *  $Id: expGperf.c,v 4.1 2005/01/01 00:12:33 bkorb Exp $
+ *  $Id: expGperf.c,v 4.8 2006/03/31 19:52:10 bkorb Exp $
  *  This module implements the expression functions that should
  *  be part of Guile.
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -20,75 +20,22 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
+#ifndef SHELL_ENABLED
+SCM
+ag_scm_make_gperf( SCM name, SCM hlist )
+{
+    return SCM_UNDEFINED;
+}
 
-tSCC zMakeGperf[] =
-"gperf_%2$s=.ZZPURGE.$$/%2$s\n"
-"[ -d .ZZPURGE.$$ ] || mkdir .ZZPURGE.$$\n"
-
-/*
- *  The following little scriplet will ensure that the junk we leave
- *  around will be removed not more than three seconds after we finish.
- *  The third argument to this format string is the process id of AutoGen.
- */
-"( ( while ps -p %3$d ; do sleep 3 ; done\n"
-"    rm -rf .ZZPURGE.$$ ) > /dev/null 2>&1 & )\n"
-
-"cd .ZZPURGE.$$ || {\n"
-"  echo 'cannot mkdir and enter .ZZPURGE.$$' >&2\n"
-"  exit 1\n}\n"
-
-"( "
-
-/*
- *  From here to the matching closing paren, we are constructing the
- *  pgerf input file with every character written to stdout
- */
-"cat <<'_EOF_'\n"
-"%%{\n"
-"#" "include <stdio.h>\n"
-"typedef struct index t_index;\n"
-"%%}\n"
-"struct index { char* name; int idx; };\n"
-"%%%%\n"
-"_EOF_\n"
-
-"idx=1\n"
-"while read f\n"
-"do echo \"${f}, ${idx}\"\n"
-"   idx=`expr ${idx} + 1`\n"
-"done <<_EOLIST_\n"
-"%1$s\n"
-"_EOLIST_\n"
-
-"cat <<'_EOF_'\n"
-"%%%%\n"
-"int main( int argc, char** argv ) {\n"
-"    char*    pz = argv[1];\n"
-"    t_index* pI = in_word_set( pz, strlen( pz ));\n"
-"    if (pI == NULL)\n"
-"        return 1;\n"
-"    printf( \"0x%%02X\\n\", pI->idx );\n"
-"    return 0;\n"
-"}\n"
-"_EOF_\n"
-
-/*
- *  Now save the text into a xx.gperf file and also pass it
- *  through a pipe to gperf for it to do its thing.
- */
-") | tee %2$s.gperf | gperf -t -D -k'*' > %2$s.c\n"
-
-/*
- *  actually build the program using "make"
- */
-"make %2$s || exit 1";
-
-
-tSCC zRunGperf[] = "${gperf_%s} %s";
-
+SCM
+ag_scm_gperf( SCM name, SCM str )
+{
+    return SCM_UNDEFINED;
+}
+#else
 
 /*=gfunc make_gperf
  *
@@ -109,11 +56,11 @@ tSCC zRunGperf[] = "${gperf_%s} %s";
 SCM
 ag_scm_make_gperf( SCM name, SCM hlist )
 {
-    SCM     newline  = gh_str2scm( "\n", 1 );
+    SCM     newline  = AG_SCM_STR2SCM( "\n", 1 );
     char*   pzName   = ag_scm2zchars( name, "gperf name" );
     char*   pzList;
 
-    if (! gh_string_p( name ))
+    if (! AG_SCM_STRING_P( name ))
         return SCM_UNDEFINED;
 
     /*
@@ -126,15 +73,25 @@ ag_scm_make_gperf( SCM name, SCM hlist )
      *  Stash the concatenated list somewhere, hopefully without an alloc.
      */
     {
+        static const int makeGperfLine = __LINE__ + 2;
+        static const char* pzCleanup =
+            "(set! shell-cleanup (string-append shell-cleanup "
+            "\"rm -rf ${gpdir}\n\"))\n";
         char* pzCmd;
-        pzCmd = aprf( zMakeGperf, pzList, pzName, getpid() );
+        pzCmd = aprf( zMakeGperf, pzList, pzName );
 
         /*
          *  Run the command and ignore the results.
          *  In theory, the program should be ready.
          */
-        AGFREE( runShell( pzCmd ));
+        pzList = runShell( pzCmd );
         AGFREE( pzCmd );
+
+        if (pzCleanup != NULL) {
+            (void)ag_scm_c_eval_string_from_file_line(
+                pzCleanup, __FILE__, makeGperfLine );
+            pzCleanup = NULL;
+        }
     }
     return SCM_BOOL_T;
 }
@@ -174,12 +131,13 @@ ag_scm_gperf( SCM name, SCM str )
     if (*pzStr == NUL)
         str = SCM_UNDEFINED;
     else
-        str = gh_str02scm( pzStr );
+        str = AG_SCM_STR02SCM( pzStr );
 
     AGFREE( pzCmd );
     AGFREE( pzStr );
     return str;
 }
+#endif
 /*
  * Local Variables:
  * mode: C
