@@ -1,13 +1,13 @@
 
 /*
  *  expState.c
- *  $Id: expState.c,v 4.8 2005/12/05 20:51:37 bkorb Exp $
+ *  $Id: expState.c,v 4.12 2006/07/22 04:50:19 bkorb Exp $
  *  This module implements expression functions that
  *  query and get state information from AutoGen data.
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -26,6 +26,25 @@
  *             Boston, MA  02110-1301, USA.
  */
 
+#ifdef SCM_HAVE_T_UINT64
+  typedef uint64_t ver_type_t;
+# define VER_UNIT_SHIFT   16ULL
+# if ((SCM_MAJOR_VERSION * 100) + SCM_MINOR_VERSION) >= 108
+#  define SCM_FROM(v)  scm_from_uint64(v)
+# else
+#  define SCM_FROM(v)  gh_ulong2scm((unsigned long)v)
+# endif
+
+#else
+  typedef uint32_t ver_type_t;
+# define VER_UNIT_SHIFT   8
+# ifdef HAVE_SCM_FROM_UINT32
+#  define SCM_FROM(v)  scm_from_uint32(v)
+# else
+#  define SCM_FROM(v)  gh_ulong2scm((unsigned long)v)
+# endif
+#endif
+
 /* = = = START-STATIC-FORWARD = = = */
 /* static forward declarations maintained by :mkfwd */
 static int
@@ -36,6 +55,9 @@ count_entries( char* pzName );
 
 static SCM
 find_entry_value( SCM op, SCM obj, SCM test );
+
+static ver_type_t
+str2int_ver( char* pz );
 /* = = = END-STATIC-FORWARD = = = */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -199,6 +221,78 @@ ag_scm_base_name( void )
 }
 
 
+/*=gfunc version_compare
+ *
+ * what:   compare two version numbers
+ * general_use:
+ *
+ * exparg: op, comparison operation
+ * exparg: v1, first version
+ * exparg: v2, compared-to version
+ *
+ * doc:  Converts v1 and v2 strings into 64 bit values and returns the
+ *       result of running 'op' on those values.  It assumes that the version
+ *       is a 1 to 4 part dot-separated series of numbers.  Suffixes like,
+ *       "5pre5" are presumed to be equal to the initial digits, e.g. "5".
+=*/
+static ver_type_t
+str2int_ver( char* pz )
+{
+    char* pzStr = pz;
+    ver_type_t  val = 0;
+    int ix = 4;
+
+    while (--ix >= 0) {
+        unsigned int v;
+        val <<= VER_UNIT_SHIFT;
+        while (isspace(*pz))  pz++;
+
+    next_number:
+        if (! isdigit(*pz)) break;
+        v = (unsigned int)strtoul(pz, &pz, 0) & ((1 << VER_UNIT_SHIFT) - 1);
+        if (pz == NULL)
+            break;
+        val += v;
+        if (*pz == '-') pz++;
+
+        switch (*pz) {
+        case 'p':
+            if ((pz[1] == 'r') && (pz[2] == 'e')) {
+                pz += 3;
+                val = (val << 2) - 1;
+                val <<= (VER_UNIT_SHIFT - 2);
+                if (--ix < 0) goto leave_str2int_ver;
+                goto next_number;
+            }
+            /* FALLTHROUGH */
+
+        default:
+            goto leave_str2int_ver;
+
+        case '.':
+            if (! isdigit( *(++pz) ))
+                goto leave_str2int_ver;
+            break;
+        }
+    } leave_str2int_ver: ;
+
+    while (--ix >= 0)  val <<= VER_UNIT_SHIFT;
+    fprintf( pfTrace, "0x%016llX <<== '%s'\n", (long long)val, pzStr );
+    return val;
+}
+
+SCM
+ag_scm_version_compare( SCM op, SCM v1, SCM v2 )
+{
+    tSCC  zVer[] = "version str";
+    ver_type_t  val1 = str2int_ver( ag_scm2zchars( v1, zVer ));
+    ver_type_t  val2 = str2int_ver( ag_scm2zchars( v2, zVer ));
+    v1 = SCM_FROM(val1);
+    v2 = SCM_FROM(val2);
+    return scm_apply( op, v1, scm_cons(v2, scm_listofnull));
+}
+
+
 /*=gfunc chdir
  *
  * what:   Change current directory
@@ -577,7 +671,7 @@ ag_scm_tpl_file_line( SCM fmt )
         pzFmt = ag_scm2zchars( fmt, "file/line format" );
 
     {
-        size_t  maxlen = strlen( pCurTemplate->pzFileName )
+        size_t  maxlen = strlen( pCurTemplate->pzTplFile )
                        + strlen( pzFmt ) + 4 * sizeof( int );
         if (maxlen >= sizeof( zScribble ))
             pz = (char*)AGALOC( maxlen, "file-line buffer" );
@@ -586,7 +680,7 @@ ag_scm_tpl_file_line( SCM fmt )
 
     {
         void* args[2];
-        args[0] = (void*)pCurTemplate->pzFileName;
+        args[0] = (void*)pCurTemplate->pzTplFile;
         args[1] = (void*)(long)pCurMacro->lineNo;
         sprintfv( pz, pzFmt, (snv_constpointer*)args  );
     }
