@@ -1,6 +1,6 @@
 
 /*
- *  $Id: funcDef.c,v 4.7 2006/03/25 19:24:49 bkorb Exp $
+ *  $Id: funcDef.c,v 4.13 2006/07/22 04:50:19 bkorb Exp $
  *
  *  This module implements the DEFINE text function.
  */
@@ -53,6 +53,7 @@ static void
 build_defs( int defCt, tDefList* pList );
 /* = = = END-STATIC-FORWARD = = = */
 
+tMacro* mLoad_Debug( tTemplate* pT, tMacro* pMac, tCC** ppzScan );
 
 static int
 orderDefList( const void* p1, const void* p2 )
@@ -119,7 +120,7 @@ LOCAL void
 parseMacroArgs( tTemplate* pT, tMacro* pMac )
 {
     char*        pzScan = pT->pzTemplText + pMac->ozText;
-    int          ct     = 0;
+    u_int        ct     = 0;
     tDefList*    pDL;
     tDefList*    pN;
 
@@ -137,8 +138,7 @@ parseMacroArgs( tTemplate* pT, tMacro* pMac )
     while (*pzScan != NUL) {
         ct++;
         if (! isalpha( *pzScan )) {
-            fprintf( stderr, "On macro argument # %d:\n%s\n",
-                     ct, pzScan );
+            fprintf( stderr, "On macro argument # %d:\n%s\n", ct, pzScan );
             AG_ABEND_IN( pT, pMac, "no macro arg name" );
         }
 
@@ -241,7 +241,7 @@ parseMacroArgs( tTemplate* pT, tMacro* pMac )
              */
             if ((pzScan - pDL->pzExpr) < 24) {
                 char* pz = (char*)AGALOC( 24, "quoted string" );
-                memcpy( (void*)pz, pDL->pzExpr, (pzScan - pDL->pzExpr) );
+                memcpy((void*)pz, pDL->pzExpr, (unsigned)(pzScan - pDL->pzExpr));
                 pDL->pzExpr = pz;
                 manageAllocatedData( pz );
             }
@@ -282,7 +282,7 @@ parseMacroArgs( tTemplate* pT, tMacro* pMac )
          *  if the strings compare equal.
          */
         pDL = (tDefList*)pMac->res;
-        qsort( (void*)pDL, ct, sizeof( tDefList ), orderDefList );
+        qsort( (void*)pDL, (size_t)ct, (size_t)sizeof(tDefList), orderDefList );
 
         /*
          *  Now, link them all together.  Singly linked list.
@@ -300,7 +300,7 @@ parseMacroArgs( tTemplate* pT, tMacro* pMac )
              *  THEN it is a "twin".  Link twins on the twin list.
              */
             if (streqvcmp( pDL->de.pzDefName, pN->de.pzDefName ) == 0) {
-                pN = linkTwins( pDL, pN, &ct );
+                pN = linkTwins( pDL, pN, (int*)&ct );
                 if (ct <= 0)
                     break;  /* pN is now invalid */
             }
@@ -447,7 +447,7 @@ build_defs( int defCt, tDefList* pList )
                 AGDUPSTR( pList->de.val.pzText, ag_scm2zchars(res, "eval res"),
                           "dup eval res" );
             }
-            else if (gh_number_p( res )) {
+            else if (AG_SCM_NUMBER_P( res )) {
                 pList->de.val.pzText = AGALOC( 16, "number buf" );
                 snprintf( pList->de.val.pzText, 16, "%ld", gh_scm2ulong( res ));
             }
@@ -491,11 +491,11 @@ build_defs( int defCt, tDefList* pList )
  *  @end example
  *
  *  Once the macro has been defined, this new macro can be invoked by
- *  specifying the macro name as the first token after the start macro
- *  marker.  Alternatively, you may make the invocation explicitly invoke a
- *  defined macro by specifying @code{INVOKE} in the macro invocation.  If
- *  you do that, the macro name can be computed with an expression that gets
- *  evaluated every time the INVOKE macro is encountered.  @xref{INVOKE}.
+ *  specifying the macro name as the first token after the start macro marker.
+ *  Alternatively, you may make the invocation explicitly invoke a defined
+ *  macro by specifying @code{INVOKE} (@pxref{INVOKE}) in the macro
+ *  invocation.  If you do that, the macro name can be computed with an
+ *  expression that gets evaluated every time the INVOKE macro is encountered.
  *
  *  Any remaining text in the macro invocation will be used to create new
  *  name/value pairs that only persist for the duration of the processing of
@@ -517,6 +517,20 @@ build_defs( int defCt, tDefList* pList )
  *  @item
  *  Sequences of strings are not concatenated.
  *  @end enumerate
+ *
+ *  @quotation
+ *  @strong{NB:} The macro is extracted from the template as the template is
+ *  scanned.  You cannot conditionally define a macro by enclosing it in an
+ *  @code{IF}/@code{ENDIF} (@pxref{IF}) macro pair.  If you need to dynamically
+ *  select the format of a @code{DEFINE}d macro, then put the flavors into
+ *  separate template files that simply define macros.  @code{INCLUDE}
+ *  (@pxref{INCLUDE}) the appropriate template when you have computed which
+ *  you need.
+ *  @end quotation
+ *
+ *  Due to this, it is acceptable and even a good idea to place all the
+ *  @code{DEFINE} macros at the end of the template.  That puts the main
+ *  body of the template at the beginning of the file.
 =*/
 /*=macfunc ENDDEF
  *
@@ -770,7 +784,7 @@ mLoad_Define( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
             int   delta = sizeof(tMacro) * (pNewT->macroCt - ct);
             void* data  = (pNewT->pzTplName == NULL) ?
                 pNewT->pzTemplText : pNewT->pzTplName;
-            int  size  = pNewT->pNext - (char*)data;
+            size_t size = pNewT->pNext - (char*)data;
             memmove( (void*)pMacEnd, data, size );
 
             pNewT->pzTemplText -= delta;
