@@ -1,12 +1,12 @@
 
 /*
- *  $Id: funcFor.c,v 4.8 2005/12/05 20:51:37 bkorb Exp $
+ *  $Id: funcFor.c,v 4.11 2006/06/24 23:36:07 bkorb Exp $
  *
  *  This module implements the FOR text macro.
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -47,7 +47,7 @@ doForEach( tTemplate*   pT,
            tDefEntry*   pFoundDef );
 
 static void
-load_ForIn( tCC* pzSrc, int srcLen, tTemplate* pT, tMacro* pMac );
+load_ForIn( tCC* pzSrc, u_int srcLen, tTemplate* pT, tMacro* pMac );
 /* = = = END-STATIC-FORWARD = = = */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -311,7 +311,7 @@ doForByStep( tTemplate* pT,
     tDefCtx     ctx       = currDefCtx;
 
     if (pFS->for_pzSep == NULL)
-        pFS->for_pzSep = "";
+        pFS->for_pzSep = (char*)zNil;
 
     /*
      *  IF the for-from and for-to values have not been set,
@@ -495,7 +495,7 @@ doForEach( tTemplate*   pT,
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 static void
-load_ForIn( tCC* pzSrc, int srcLen, tTemplate* pT, tMacro* pMac )
+load_ForIn( tCC* pzSrc, u_int srcLen, tTemplate* pT, tMacro* pMac )
 {
     char* pzName = pT->pzTemplText + pMac->ozName;
     int   ix     = 0;
@@ -517,6 +517,7 @@ load_ForIn( tCC* pzSrc, int srcLen, tTemplate* pT, tMacro* pMac )
         pz = AGALOC( srcLen + 2 + nmlen, "copy of FOR x IN ... text" );
         strcpy( pz, pzName );
         pzName = pz;
+        manageAllocatedData(pz);
         pz += nmlen + 1;
     }
 
@@ -699,7 +700,7 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
                          pT->pzTemplText + pMac->ozName );
 
                 if (OPT_VALUE_TRACE < TRACE_EVERYTHING)
-                    fprintf( pfTrace, zFileLine, pT->pzFileName, pMac->lineNo );
+                    fprintf( pfTrace, zFileLine, pT->pzTplFile, pMac->lineNo );
             }
 
             return pMRet;
@@ -724,7 +725,7 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
 
     if (OPT_VALUE_TRACE >= TRACE_BLOCK_MACROS)
         fprintf( pfTrace, "FOR %s loop in %s on line %d begins:\n",
-                 pT->pzTemplText + pMac->ozName, pT->pzFileName,
+                 pT->pzTemplText + pMac->ozName, pT->pzTplFile,
                  pMac->lineNo );
 
     if (pT->pzTemplText[ pMac->ozText ] == '(') {
@@ -748,7 +749,7 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
                  pT->pzTemplText + pMac->ozName, loopCt );
 
         if (OPT_VALUE_TRACE < TRACE_EVERYTHING)
-            fprintf( pfTrace, zFileLine, pT->pzFileName, pMac->lineNo );
+            fprintf( pfTrace, zFileLine, pT->pzTplFile, pMac->lineNo );
     }
 
     return pMRet;
@@ -822,7 +823,7 @@ mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      */
     else if (   (strneqvcmp( pzSrc, "in", 2 ) == 0)
              && isspace( pzSrc[2] )) {
-        load_ForIn( pzSrc, srcLen, pT, pMac );
+        load_ForIn( pzSrc, (unsigned)srcLen, pT, pMac );
     }
 
     /*
