@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sun Apr  9 11:49:58 PDT 2006
+ * Generated Sat Aug 12 10:37:39 PDT 2006
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -49,6 +49,9 @@ runShell( const char*  pzCmd );
 LOCAL char*
 aprf( const char* pzFmt, ... );
 
+LOCAL char*
+mkstempPat( void );
+
 LOCAL void
 doOptions( int arg_ct, char** arg_vec );
 
@@ -149,10 +152,10 @@ parseMacroArgs( tTemplate* pT, tMacro* pMac );
 /*
  *  Extracted from funcEval.c
  */
-LOCAL char*
+LOCAL tCC*
 resolveSCM( SCM s );
 
-LOCAL char*
+LOCAL tCC*
 evalExpression( ag_bool* pMustFree );
 
 LOCAL SCM
