@@ -1,12 +1,12 @@
 
 /*
- *  $Id: tpLoad.c,v 4.10 2006/01/24 23:22:17 bkorb Exp $
+ *  $Id: tpLoad.c,v 4.11 2006/06/24 23:36:07 bkorb Exp $
  *
  *  This module will load a template and return a template structure.
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -272,10 +272,10 @@ loadMacros( tTemplate* pT,
          *  THEN pack the text
          */
         if (ct < pT->macroCt) {
-            int   delta = sizeof(tMacro) * (pT->macroCt - ct);
-            void* data  =
+            int     delta = sizeof(tMacro) * (pT->macroCt - ct);
+            void*   data  =
                 (pT->pzTplName == NULL) ? pT->pzTemplText : pT->pzTplName;
-            int   size  = pT->pNext - (char*)data;
+            size_t  size  = pT->pNext - (char*)data;
             memmove( (void*)pMacEnd, data, size );
 
             pT->pzTemplText -= delta;
