@@ -1,8 +1,8 @@
 
 /*
- *  Time-stamp:      "2005-10-29 15:06:44 bkorb"
+ *  Time-stamp:      "2006-08-12 10:26:19 bkorb"
  *
- *  autoopts.h  $Id: autoopts.h,v 4.16 2005/11/07 00:22:05 bkorb Exp $
+ *  autoopts.h  $Id: autoopts.h,v 4.14 2006/08/12 17:36:43 bkorb Exp $
  *  Time-stamp:      "2005-02-14 05:59:50 bkorb"
  *
  *  This file defines all the global structures and special values
@@ -10,7 +10,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2005 Bruce Korb
+ *  Automated Options copyright 1992-2006 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -76,6 +76,12 @@
 #undef  EXPORT
 #define EXPORT
 
+#if defined(_WIN32) && !defined(__CYGWIN__)
+# define DIRCH '\\'
+#else
+# define DIRCH '/'
+#endif
+
 /*
  *  Convert the number to a list usable in a printf call
  */
@@ -101,7 +107,18 @@ typedef int tDirection;
  *
  *  USAGE:  define procedures to return "tSuccess".  Test their results
  *          with the SUCCEEDED, FAILED and HADGLITCH macros.
+ *
+ *  Microsoft sticks its nose into user space here, so for Windows' sake,
+ *  make sure all of these are undefined.
  */
+#undef  SUCCESS
+#undef  FAILURE
+#undef  PROBLEM
+#undef  SUCCEEDED
+#undef  SUCCESSFUL
+#undef  FAILED
+#undef  HADGLITCH
+
 #define SUCCESS  ((tSuccess) 0)
 #define FAILURE  ((tSuccess)-1)
 #define PROBLEM  ((tSuccess) 1)
@@ -178,16 +195,12 @@ typedef struct {
     tCC*    pzOptFmt;
 } arg_types_t;
 
-#  define AGALOC( c, w )        malloc( c )
-#  define AGREALOC( p, c, w )   realloc( p, c )
+#  define AGALOC( c, w )        malloc( (unsigned)c )
+#  define AGREALOC( p, c, w )   realloc( p, (unsigned)c )
 #  define AGFREE( p )           free( p )
 #  define AGDUPSTR( p, s, w )   p = strdup( s )
 #  define TAGMEM( m, t )
 
-#ifdef AUTOGEN_BUILD
-#  include <snprintfv/printf.h>
-#endif /* AUTOGEN_BUILD */
-
 /*
  *  DO option handling?
  *
@@ -292,6 +305,11 @@ typedef struct {
 # endif
 #endif
 
+#ifndef HAVE_STRCHR
+extern char* strchr( const char *s, int c);
+extern char* strrchr( const char *s, int c);
+#endif
+
 /*
  *  Define and initialize all the user visible strings.
  *  We do not do translations.  If translations are to be done, then
@@ -307,9 +325,6 @@ extern FILE* option_usage_fp;
 
 extern tOptProc optionPrintVersion, optionPagedUsage, optionLoadOpt;
 
-#define LOCAL static
-#include "proto.h"
-
 #endif /* AUTOGEN_AUTOOPTS_H */
 /*
  * Local Variables:
