@@ -1,12 +1,12 @@
 /*
- *  $Id: configfile.c,v 4.10 2005/07/27 17:26:32 bkorb Exp $
- *  Time-stamp:      "2005-07-27 10:09:29 bkorb"
+ *  $Id: configfile.c,v 1.10 2006/07/14 04:31:37 bkorb Exp $
+ *  Time-stamp:      "2006-07-01 12:46:31 bkorb"
  *
  *  configuration/rc/ini file handling.
  */
 
 /*
- *  Automated Options copyright 1992-2005 Bruce Korb
+ *  Automated Options copyright 1992-2006 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -148,7 +148,7 @@ configFileLoad( const char* pzFile )
     char* pzText =
         text_mmap( pzFile, PROT_READ, MAP_PRIVATE, &cfgfile );
 
-    if (pzText == MAP_FAILED)
+    if (TEXT_MMAP_FAILED_ADDR(pzText))
         return NULL; /* errno is set */
 
     pRes = optionLoadNested(pzText, pzFile, strlen(pzFile), OPTION_LOAD_COOKED);
@@ -444,7 +444,7 @@ filePreset(
         text_mmap( pzFileName, PROT_READ|PROT_WRITE, MAP_PRIVATE, &cfgfile );
     tOptState     st = OPTSTATE_INITIALIZER(PRESET);
 
-    if (pzFileText == MAP_FAILED)
+    if (TEXT_MMAP_FAILED_ADDR(pzFileText))
         return;
 
     if (direction == DIRECTION_CALLED) {
@@ -640,7 +640,7 @@ handleDirective(
 
         if (isspace(*pzText)) {
             while (isspace(*pzText))  pzText++;
-            if (  (strneqvcmp( pzText, pOpts->pzProgName, name_len ) == 0)
+            if (  (strneqvcmp( pzText, pOpts->pzProgName, (int)name_len) == 0)
                && (pzText[name_len] == '>'))  {
                 pzText += name_len + 1;
                 break;
@@ -847,8 +847,8 @@ internalFileLoad( tOptions* pOpts )
                 continue;
 
             pz = zFileName + len;
-            if (pz[-1] != '/')
-                *(pz++) = '/';
+            if (pz[-1] != DIRCH)
+                *(pz++) = DIRCH;
             strcpy( pz, pOpts->pzRcName );
         }
 
@@ -1249,7 +1249,7 @@ validateOptionsStruct( tOptions* pOpts, const char* pzProgram )
      *  and the set of equivalent characters.
      */
     if (pOpts->pzProgName == NULL) {
-        const char* pz = strrchr( pzProgram, '/' );
+        const char* pz = strrchr( pzProgram, DIRCH );
 
         if (pz == NULL)
              pOpts->pzProgName = pzProgram;
