@@ -1,7 +1,7 @@
 
 /*
- *  $Id: load.c,v 4.16 2005/09/04 21:11:16 bkorb Exp $
- *  Time-stamp:      "2005-07-31 08:41:52 bkorb"
+ *  $Id: load.c,v 4.11 2006/07/14 04:31:37 bkorb Exp $
+ *  Time-stamp:      "2006-07-01 12:43:03 bkorb"
  *
  *  This file contains the routines that deal with processing text strings
  *  for options, either from a NUL-terminated string passed in or from an
@@ -9,7 +9,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2005 Bruce Korb
+ *  Automated Options copyright 1992-2006 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -75,10 +75,10 @@ assembleArgValue( char* pzTxt, tOptionLoadMode mode );
  * private:
  *
  * what:  translate and construct a path
- * arg:   + char* + pzBuf      + The result buffer +
- * arg:   + int   + bufSize    + The size of this buffer +
- * arg:   + tCC*  + pzName     + The input name +
- * arg:   + tCC*  + pzProgPath + The full path of the current program +
+ * arg:   + char*       + pzBuf      + The result buffer +
+ * arg:   + int         + bufSize    + The size of this buffer +
+ * arg:   + const char* + pzName     + The input name +
+ * arg:   + const char* + pzProgPath + The full path of the current program +
  *
  * ret-type: ag_bool
  * ret-desc: AG_TRUE if the name was handled, otherwise AG_FALSE.
@@ -102,7 +102,7 @@ assembleArgValue( char* pzTxt, tOptionLoadMode mode );
  *
  *  Please note: both @code{$$} and @code{$NAME} must be at the start of the
  *     @code{pzName} string and must either be the entire string or be followed
- *     by the @code{'/'} character.
+ *     by the @code{'/'} (backslash on windows) character.
  *
  * err:  @code{AG_FALSE} is returned if:
  *       @*
@@ -195,7 +195,7 @@ insertProgramPath(
     int     skip = 2;
 
     switch (pzName[2]) {
-    case '/':
+    case DIRCH:
         skip = 3;
     case NUL:
         break;
@@ -208,7 +208,7 @@ insertProgramPath(
      *  If it is, we're done.  Otherwise, we have to hunt
      *  for the program using "pathfind".
      */
-    if (strchr( pzProgPath, '/' ) != NULL)
+    if (strchr( pzProgPath, DIRCH ) != NULL)
         pzPath = pzProgPath;
     else {
         pzPath = pathfind( getenv( "PATH" ), (char*)pzProgPath, "rx" );
@@ -217,7 +217,7 @@ insertProgramPath(
             return AG_FALSE;
     }
 
-    pz = strrchr( pzPath, '/' );
+    pz = strrchr( pzPath, DIRCH );
 
     /*
      *  IF we cannot find a directory name separator,
@@ -235,7 +235,7 @@ insertProgramPath(
     if ((pz - pzPath)+1 + strlen(pzName) >= bufSize)
         return AG_FALSE;
 
-    memcpy( pzBuf, pzPath, (pz - pzPath)+1 );
+    memcpy( pzBuf, pzPath, (unsigned)((pz - pzPath)+1) );
     strcpy( pzBuf + (pz - pzPath) + 1, pzName );
 
     /*
